@@ -1,39 +1,39 @@
 from applitools.common import (
     DeviceName,
+    FileLogger,
     MatchLevel,
+    RectangleSize,
     Region,
     StdoutLogger,
-    FileLogger,
-    logger,
-    RectangleSize,
-    TestResults,
     TestResultContainer,
+    TestResults,
     TestResultsSummary,
+    logger,
+)
+from applitools.common.accessibility import (  # noqa
+    AccessibilityGuidelinesVersion,
+    AccessibilityLevel,
+    AccessibilityRegionType,
+    AccessibilitySettings,
 )
-from applitools.common.ultrafastgrid import (
-    IosDeviceInfo,
-    ScreenOrientation,
-    IosDeviceName,
-    ChromeEmulationInfo,
-    DesktopBrowserInfo,
-)  # noqa
-from applitools.common.geometry import AccessibilityRegion
 from applitools.common.config import BatchInfo  # noqa
+from applitools.common.geometry import AccessibilityRegion
 from applitools.common.selenium import BrowserType, Configuration, StitchMode  # noqa
 from applitools.common.server import FailureReports  # noqa
+from applitools.common.ultrafastgrid import (  # noqa
+    ChromeEmulationInfo,
+    DesktopBrowserInfo,
+    IosDeviceInfo,
+    IosDeviceName,
+    ScreenOrientation,
+)
+from applitools.core.batch_close import BatchClose  # noqa
 from applitools.core.cut import (  # noqa
     FixedCutProvider,
     NullCutProvider,
     UnscaledFixedCutProvider,
 )
-from applitools.common.accessibility import (  # noqa
-    AccessibilityRegionType,
-    AccessibilitySettings,
-    AccessibilityLevel,
-    AccessibilityGuidelinesVersion,
-)
 from applitools.core.fluent.region import AccessibilityRegionByRectangle  # noqa
-from applitools.core.batch_close import BatchClose  # noqa
 
 from .classic_runner import ClassicRunner  # noqa
 from .eyes import Eyes  # noqa
