@@ -2,13 +2,13 @@ from __future__ import absolute_import
 
 import typing
 
-from applitools.common import EyesError, logger, MatchResult
+from applitools.common import EyesError, MatchResult, logger
 from applitools.common.selenium import Configuration
 from applitools.common.utils import argument_guard
 from applitools.common.utils.general_utils import all_fields, proxy_to
-from applitools.core.eyes_mixins import EyesConfigurationMixin
 from applitools.core.eyes_base import DebugScreenshotsAbstract
-from applitools.core.locators import VisualLocatorSettings, LOCATORS_TYPE
+from applitools.core.eyes_mixins import EyesConfigurationMixin
+from applitools.core.locators import LOCATORS_TYPE, VisualLocatorSettings
 from applitools.core.server_connector import ServerConnector
 from applitools.selenium import ClassicRunner, eyes_selenium_utils
 
@@ -19,23 +19,26 @@ from .visual_grid import VisualGridEyes, VisualGridRunner
 from .webdriver import EyesWebDriver
 
 if typing.TYPE_CHECKING:
-    from typing import Text, Optional, Union, List, Tuple
+    from typing import List, Optional, Text, Tuple, Union
+
     from selenium.webdriver.remote.webelement import WebElement
-    from applitools.common import TestResults, Region, MatchLevel
+
+    from applitools.common import MatchLevel, Region, TestResults
     from applitools.common.utils.custom_types import (
         AnyWebDriver,
-        ViewPort,
-        FrameReference,
         AnyWebElement,
+        FrameReference,
+        ViewPort,
     )
     from applitools.core import (
-        PositionProvider,
         FixedCutProvider,
-        UnscaledFixedCutProvider,
         NullCutProvider,
+        PositionProvider,
+        UnscaledFixedCutProvider,
     )
-    from .frames import FrameChain
+
     from .fluent import SeleniumCheckSettings
+    from .frames import FrameChain
     from .webelement import EyesWebElement
 
 
@@ -156,7 +159,7 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
     @property
     def original_fc(self):
         # type: () -> Optional[FrameChain]
-        """ Gets original frame chain
+        """Gets original frame chain
 
         Before check() call we save original frame chain
 
@@ -500,11 +503,6 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         if self.configure.is_disabled:
             logger.info("open(): ignored (disabled)")
             return
-        logger.info(
-            "open(app_name={}, test_name={}, viewport_size={})".format(
-                app_name, test_name, viewport_size
-            )
-        )
         if app_name:
             self.configure.app_name = app_name
         if test_name:
@@ -519,6 +517,14 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
             self.configure.test_name, ValueError("test_name is required")
         )
 
+        logger.info(
+            "open(app_name={}, test_name={}, viewport_size={})".format(
+                self.configure.app_name,
+                self.configure.test_name,
+                self.configure.viewport_size,
+            )
+        )
+
         self._init_driver(driver)
         self._init_locator_provider()
         if self._is_visual_grid_eyes:
