@@ -11,24 +11,25 @@ from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.remote.webdriver import WebDriver
 from selenium.webdriver.remote.webelement import WebElement
 
-from applitools.common import Point, RectangleSize, logger, EyesError
+from applitools.common import EyesError, Point, RectangleSize, logger
 from applitools.common.utils import datetime_utils
+from applitools.common.utils.compat import urlparse
 
 if tp.TYPE_CHECKING:
-    from typing import Text, Optional, Any, Union, Generator, Dict
+    from typing import Any, Dict, Generator, Optional, Text, Union
+
+    from applitools.common.utils.custom_types import (
+        AnyWebDriver,
+        AnyWebElement,
+        Num,
+        ViewPort,
+    )
     from applitools.core import PositionProvider
+    from applitools.selenium.fluent import FrameLocator, SeleniumCheckSettings
     from applitools.selenium.frames import FrameChain
     from applitools.selenium.positioning import SeleniumPositionProvider
     from applitools.selenium.webdriver import EyesWebDriver
     from applitools.selenium.webelement import EyesWebElement
-    from applitools.selenium.fluent import SeleniumCheckSettings, FrameLocator
-
-    from applitools.common.utils.custom_types import (
-        AnyWebDriver,
-        ViewPort,
-        AnyWebElement,
-        Num,
-    )
 
 __all__ = (
     "get_current_frame_content_entire_size",
@@ -606,3 +607,16 @@ def get_dom_script_result(driver, dom_extraction_timeout, timer_name, script_for
     if script_result is None or status == "ERROR":
         raise EyesError("Failed to capture script_result")
     return script_result
+
+
+def get_app_name(driver):
+    caps = driver.desired_capabilities
+    return caps.get("appPackage", None) or caps.get("app", "").split("/")[-1] or None
+
+
+def get_webapp_domain(driver):
+    return urlparse(driver.current_url).hostname
+
+
+def get_check_source(driver):
+    return get_app_name(driver) if is_mobile_app(driver) else get_webapp_domain(driver)
