@@ -5,17 +5,13 @@ from copy import copy
 
 import attr
 
-from applitools.common import (
-    EyesError,
-    TestResults,
-    logger,
-)
-from applitools.common.utils import argument_guard
+from applitools.common import EyesError, TestResults, logger
 from applitools.common.ultrafastgrid import (
+    DesktopBrowserInfo,
     RenderBrowserInfo,
     VisualGridSelector,
-    DesktopBrowserInfo,
 )
+from applitools.common.utils import argument_guard
 from applitools.core import CheckSettings, GetRegion, ServerConnector
 from applitools.selenium import __version__, eyes_selenium_utils, resource
 from applitools.selenium.fluent import SeleniumCheckSettings
@@ -26,9 +22,10 @@ from .running_test import RunningTest
 from .visual_grid_runner import VisualGridRunner
 
 if typing.TYPE_CHECKING:
-    from typing import List, Text, Union, Optional, Dict
+    from typing import Dict, List, Optional, Text, Union
+
     from applitools.common.utils.custom_types import AnyWebElement
-    from applitools.selenium import Eyes, EyesWebDriver, Configuration
+    from applitools.selenium import Configuration, Eyes, EyesWebDriver
 
 
 GET_ELEMENT_XPATH_JS = """
@@ -181,6 +178,7 @@ class VisualGridEyes(object):
         region_xpaths = self.get_region_xpaths(check_settings)
         logger.info("region_xpaths: {}".format(region_xpaths))
         script_result = self.get_script_result()
+        source = eyes_selenium_utils.get_check_source(self.driver)
         try:
             for test in self.test_list:
                 if self._test_uuid != test.test_uuid:
@@ -193,6 +191,7 @@ class VisualGridEyes(object):
                     region_selectors=region_xpaths,
                     region_to_check=check_settings.values.target_region,
                     script_hooks=check_settings.values.script_hooks,
+                    source=source,
                 )
                 if test.state == "new":
                     test.becomes_not_rendered()
